@@ -1,3 +1,7 @@
+( cd opt/kde/lib ; rm -rf libkhexeditcommon.so.0 )
+( cd opt/kde/lib ; ln -sf libkhexeditcommon.so.0.0.0 libkhexeditcommon.so.0 )
+( cd opt/kde/lib ; rm -rf libkhexeditcommon.so )
+( cd opt/kde/lib ; ln -sf libkhexeditcommon.so.0.0.0 libkhexeditcommon.so )
 ( cd opt/kde/lib ; rm -rf libkcmlaptop.so )
 ( cd opt/kde/lib ; ln -sf libkcmlaptop.so.0.0.0 libkcmlaptop.so )
 ( cd opt/kde/lib ; rm -rf libksimcore.so )
